@@ -1,8 +1,8 @@
 #!/usr/bin/env -S guile -e start -s
 !#
 ;;; coding: utf-8
-;;; $Id: debian-copyrighter.scm,v 1.73 2025/02/13 16:25:55 fpp Exp $
-;;; Copyright © 2022-2025 Frank Pursel <frank.pursel@gmail.com>
+;;; $Id: debian-copyrighter.scm,v 1.40 2022/12/16 17:46:04 fpp Exp fpp $
+;;; Copyright © 2022 Frank Pursel <frank.pursel@gmail.com>
 
  ;; The debian-copyrighter is free software; you can redistribute it and/or modify it
  ;; under the terms of the GNU General Public License as published by
@@ -27,15 +27,18 @@
  (ice-9 getopt-long)
  (ice-9 format)
  (ice-9 ftw)
- (ice-9 match)
  (srfi srfi-1)
  (srfi srfi-9)
  (srfi srfi-9 gnu)
  (srfi srfi-11)
  (ice-9 regex)
  (ice-9 rdelim)
- (srfi srfi-64)
- (srfi srfi-26))
+ (srfi srfi-64))
+
+;; Default project data.
+(define project-name "guix")
+(define project-license 'GPL-3.0+)
+(define project-source "https://ftp.gnu.org/gnu/guix")
 
 (define-record-type <licensed-file>
   (make-licensed-file full-name dir license copyright-list)
@@ -44,22 +47,12 @@
   (dir licensed-file-dir set-licensed-file-dir!)
   (license licensed-file-license set-licensed-file-license!)
   (copyright-list licensed-file-copyright-list set-licensed-file-copyright-list!))
-
-(define (licensed-file-license->string rec)
-  "license must be a symbol for processing but then a string at output."
-  (let ((lfl (licensed-file-license rec)))
-    (if lfl
-	(symbol->string (licensed-file-license rec))
-	"No License Found")))
-
 (define-record-type <copyright>
   (make-copyright tag year-list)
   copyright?
   (tag copyright-tag set-copyright-tag!)
   (year-list copyright-year-list set-copyright-year-list!))
 
-(define diagnostic-str "Done!\n")
-
 ;;; Tools to compress a list of numeric years.
 (define (group-adj-aux sorted-l res)
   (if (null? sorted-l)
@@ -106,7 +99,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 	  (#t  (let* ((sorted-num-list (sort yr-lst <=))
 		      (min-yr (car sorted-num-list))
 		      (max-yr (car (reverse sorted-num-list))))
-		 (format #f "~a-~a" min-yr max-yr)))
+		 (format #f "~a,~a" min-yr max-yr)))
 	  )
     )
   )
@@ -132,15 +125,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 
 (define (expand-hyphen-yrs h-yr-str)
   (let* ((str-l (string-split h-yr-str (string-ref h-yr-str 4)))
-	 (fixed-2digit-str-l (map (lambda (ns)
-				    (if (= (string-length ns) 4)
-					ns
-					(let ((num (string->number ns)))
-					  (if (> 50 num)
-					      (format #f "~a" (+ 2000 num))
-					      (format #f "~a" (+ 1900 num))))))
-				  str-l))
-	 (n-lst (sort (map string->number fixed-2digit-str-l) <=))
+	 (n-lst (sort (map string->number str-l) <=))
 	 (low (car n-lst))
 	 (high (cadr n-lst)))
     (string-join (map number->string (iota (- high low -1) low)) ",")
@@ -148,8 +133,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
   )
 
 
-;;(define hy-yrs-cre-old (make-regexp "(19|20)[8,9,0,1,2][0-9][-–](19|20)[8,9,0,1,2][0-9]"))
-(define hy-yrs-cre (make-regexp "(19|20)[8,9,0,1,2][0-9][-–][0-9][0-9]+"))
+(define hy-yrs-cre (make-regexp "(19|20)[8,9,0,1,2][0-9][-–](19|20)[8,9,0,1,2][0-9]"))
 
 (define (dehyphenate-line str)
   (let ((match? (regexp-exec hy-yrs-cre str)))
@@ -168,21 +152,9 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 ;(test-end "Line dehyphenation")
 
 
-(define (canon-year n)
-  (if (< n 100)
-      (if (> n 50)
-	  (+ n 1900)
-	  (+ n 2000))
-      n))
-
 (define (years-str->nlst str)
-  (let ((dehyphenated (dehyphenate-line
-		       str)))
-    (map canon-year
-	 (filter number?
-		 (map string->number
-		      (map string-trim-both (string-split dehyphenated #\,)))))
-    )
+  (let ((dehyphenated (dehyphenate-line str)))
+    (filter number? (map string->number (map string-trim-both (string-split dehyphenated #\,)))))
   )
 
 ;; (test-begin "strings-to-lists-of-numbers")
@@ -202,11 +174,6 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
    '(GPL-3.0+ "same license as the( GNU)* guix package")
    '(GPL-2.0+ "GNU General Public License" "version 2" "any later")
    '(GPL-2or3 "GNU General Public License" "version 2" "version 3")
-   '(GPL-2.0 "GNU " "Public License" "Version 2")
-   '(GPL-2.0 "GNU General Public" "License version 2")
-   '(GPL-2.0 "GNU GPL version 2")
-   '(GPL "GNU General Public")
-   '(BEER-WARE "BEER-WARE LICENSE")
    '(LGPL-2.1+ "GNU Lesser General Public"
 	       "version 2.1" "any later")
    '(LGPL-3.0+ "GNU Lesser General Public"
@@ -219,8 +186,6 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 		  "1" "2" "AS IS")
    '(BSD-3-Clause "Redistribution" "provided that the following conditions are met:"
 		  "Neither the name of the author nor the names of contributors")
-   '(Modified-BSD-4 "Redistribution and use" "software must not be misrepresented" "altered source versions must be plainly marked")
-   '(BSD-style "BSD-style license")
    '(Expat "Permission is hereby granted, free of charge, to any person obtaining")
    '(MIT "MIT License")
    '(PERMISSIVE "This file can be copied and used freely without restrictions."
@@ -236,20 +201,13 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 	 (result '() (cons line result)))
 	((eof-object? line) (begin (close-port iport) (reverse result))))))
 
-(define (line-n n lof)
-  "Diagnostic helper.  Finding a line-no from a file."
-  (car (drop lof n)))
-
 (define (file-contains-icase? re)
   (let ((compiled-re (make-regexp re regexp/icase)))
     (lambda (lof)
       (any (lambda (l-of-f) (regexp-exec compiled-re l-of-f)) lof)))
   )
 
-(define (lof-contains-license? lof)
-  (or ((file-contains-icase? " license") lof)
-      ((file-contains-icase? " Redistribution and use ") lof)
-     ))
+(define lof-contains-license? (file-contains-icase? " license "))
 
 (define (dir-from-full-file-name ffn)
   (string-join (reverse (cdr (reverse (string-split ffn #\/)))) "/"))
@@ -274,40 +232,16 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 ;;   (test-assert (not ((test-lic? (list 'x-sym "A" "tree")) "A buffalo")))
 ;;   (test-assert (eq? 'xsym ((test-lic? (list 'xsym "A" "tree")) "A tree and more"))))
 
-;(define years-re (make-regexp "(20|19)[8,9,0,1,2][0-9][ \t]?[-–,]?[ \t]?[0-9][0-9]+"))
-(define years-re (make-regexp "[-–,0-9][-–,0-9[:space:]]+"))
+(define years-re (make-regexp "((20|19)[8,9,0,1,2][0-9][-–,]? ?)+"))
 
 
-(define (make-copyright-from match) 
-  (let* (
-	 (copyright-info (match:substring match 4))
-	 (years-mat (regexp-exec years-re copyright-info))
-	 (years-str (if years-mat
-			(match:substring years-mat)
-					; (match:substring match)
-			""
-			))
-	 ;; (tag-str (fold
-	 ;; 	   (lambda (c s) (string-trim-both s c))
-	 ;; 	   (if years-mat
-	 ;; 	       (if (equal? "" (match:prefix years-mat))
-	 ;; 		   (string-drop copyright-info (string-length years-str))
-	 ;; 		   (match:prefix years-mat))
-	 ;; 	       copyright-info)
-	 ;; 	   ;; Note that order and repetitions matter here.
-	 ;; 	   (list #\space #\tab #\: #\. #\- #\* #\* #\\ #\/ #\; #\% #\space #\tab)))
-	 (tag-str (string-trim-both (if years-mat
-					(if (string-match "[^[:space:]]+" (match:prefix years-mat))
-					    ;; years are at end of citation
-					    (match:prefix years-mat)
-					    ;; years at begin of citation, drop them
-					    (string-drop copyright-info (string-length years-str))
-					    )
-					copyright-info)))
-	 )
-    (if (> 0 (string-length tag-str))
-	"Empty Copyright Tag"
-	(make-copyright tag-str (years-str->nlst years-str)))))
+(define (make-copyright-from match)
+  (let* ((years-mat (regexp-exec years-re (match:suffix match)))
+	 (years-str (if years-mat (match:substring years-mat) (match:substring match)))
+	 (tag-str (if years-mat
+		      (string-drop (match:suffix match) (string-length years-str))
+		      (match:substring match))))
+    (make-copyright tag-str (years-str->nlst years-str))))
   
 
 (define copyr-re (make-regexp
@@ -317,123 +251,15 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 			 ") "))
 		  regexp/icase))
 
-;; (define copyr-re-i (make-regexp
-;; 		  (string-concatenate
-;; 		   (list "copyright( \\([Cc]\\)| "
-;; 			 (list->string (list #\x00A9))
-;; 			 ")* "))
-;; 		  regexp/icase))
-
-;; (define copyr-re-i (make-regexp
-;; 		    (string-concatenate
-;; 		     (list "(copyright|!copyright notice|!copyright HOLD)[[:space:]0-9]+(\\([Cc]\\)|"
-;; 			   (list->string (list #\x00A9))
-;; 			   ")[[:space:]]*(.*)"))
-;; 		    regexp/icase))
-
-;; (define (copyrights-of-aux lof)
-;;   (if (null? lof)
-;;       '()
-;;       (let ((match? (regexp-exec copyr-re-i (car lof))))
-;; 	(if match?
-;; 	    (cons
-;; 	     (make-copyright-from match?)
-;; 	     (copyrights-of-aux (cdr lof)))
-;; 	    (copyrights-of-aux (cdr lof))))))
-
-;; A regexp for copyright lines (possibly incomplete)  the fourth substring would be the tag.
-(define re-copyright (make-regexp
-		      "(\\([Cc]\\)|©)?[[:space:]]*(copyright (\\([Cc]\\)|©)|copyright |!copyright notice|!copyright hold)(.*)"
-		      regexp/icase))
-
-;;; The following was added to prevents an extra empty comment line from causing the two-liner copyright from
-;;; failure in u-boot/**/drivers/spi/stm32_qspi.c
-(define empty-comment-line-re (make-regexp " *[[:space:]]+$" ))  
-(define (truncated-lof lof)
-  "Truncate lines beyond some max value, then remove empty lines from what remains.  Return a shorter lof list."
-  (let* ((max-lines 75)
-	 (new-lof (take lof max-lines)))
-    (reverse (let r ((lines new-lof)
-		     (res '()))
-	       (if (null? lines)
-		   res
-		   (let ((empty? (regexp-exec empty-comment-line-re (car lines))))
-		     (if empty?
-			 (r (cdr lines) res)
-			 (r (cdr lines) (cons (car lines) res))))))))
-  )
-
-
-;; enabling two-line copyrights.
-
-(define (copyrights-of-aux ilof)
-  (let* (
-	 ;; (lof (truncated-lof ilof))  ; Fails, cause not yet identified.
-	 (lof ilof)
-	 (len-lof (length lof))
-	 (indices-data (map (lambda (x y) (cons y x))
-			    lof
-			    (iota len-lof)))
-	 (indices-copyrights (map (lambda (x y) (cons y (regexp-exec re-copyright x)))
-				  lof
-				  (iota (length lof))))
-	 ;; Removing non-copyright-matching lines.  This list contains ONLY lead-copyr data.
-	 (indices-matches (remove (lambda (x) (not (cdr x))) indices-copyrights))
-	 ;; If the next seq line contains a lead-copyr then it must be a one-liner.
-	 ;; otherwise we can consider a two-line copyr.
-	 ;; Need to add the line following the last copyright containing line -- bc a two-liner is possible.
-         )
-    (if (null? indices-matches)
-	'()
-	(let* (
-	       (last-lead-copyr-line-no (caar (reverse indices-matches)))
-	       (extra-indices-match (car (drop indices-copyrights last-lead-copyr-line-no)))
-	       (indices-with-match-data (reverse (cons extra-indices-match (reverse indices-matches))))
-	       (poss-lead-two-liners? (map (lambda (x y)
-					     (cons* (> (car y) (1+ (car x)))
-						    ;; next line is not a lead-copyr 
-					            ;; so, it could be, the tail of the first.
-					            ;; if needed must pull from indices-data.
-						    x y)) 
-					   (take indices-with-match-data (- (length indices-with-match-data) 1))
-					   (cdr indices-with-match-data) ;; next-lead-copyright, index . copyr-match
-					   )
-				      )
-	       (join-lines (lambda (indices-match-elem)
-			     (let* ((lead-line-number (car indices-match-elem))
-				    (l1-match (cdr (assv lead-line-number indices-copyrights)))
-				    (next-line (1+ lead-line-number))
-				    (l2-data (cdr (assv next-line indices-data)))
-				    (prefix-len (string-length (string-trim-right (match:prefix l1-match))))
-				    )
-			       (string-append
-				(match:substring l1-match) " "
-				(substring l2-data prefix-len (string-length l2-data)))
-			       )))
-	       (remove-digits (lambda (str)
-				(if (string-match "[[:digit:]]+" str)
-				    (regexp-substitute #f (string-match "[[:digit:]]+" str) 'pre "" 'post)
-				    str)))
-	       (lead-copyr-str-tag (lambda (index-match) (string-trim (remove-digits (match:substring (cdr index-match) 4)))))
-	       ;; If the lead-copyr-str-tag without digits is empty then we think it is a two-liner
-	       (compute-copyright (lambda (line) (make-copyright-from
-						  (regexp-exec re-copyright line)
-						  ) ))
-	       )
-	  (map (lambda (im) 
-		 (if (string=? (lead-copyr-str-tag im) "")
-		     (compute-copyright (join-lines im)) ;; copyright from two-liners
-		     (make-copyright-from (cdr im)) ;; copyright from one-liner match data
-		     ))                           
-	       indices-matches)))))
-
-
-;;; Enabling additional testing
-(define (copyright-from-str str)
-  (let ((m? (regexp-exec re-copyright str)))
-    (if m?
-	(make-copyright-from m?)
-	#f)))
+(define (copyrights-of-aux lof)
+  (if (null? lof)
+      '()
+      (let ((match? (regexp-exec copyr-re (car lof))))
+	(if match?
+	    (cons
+	     (make-copyright-from match?)
+	     (copyrights-of-aux (cdr lof)))
+	    (copyrights-of-aux (cdr lof))))))
 
 (define copyright-po-cre (make-regexp "([-–,] ?(20|19)[8,9,1,2][0-9])+\\.?[[:blank:]]*$"))
 
@@ -478,15 +304,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 				   name
 				   (dir-from-full-file-name name)
 				   (license-of lof license-tests)
-				   ;;; Flagging copyright problems
-				   (let ((copyrights 
-					   (copyrights-of lof (basename name))))
-				     (if (every copyright? copyrights)
-					 copyrights
-					 (begin
-					   (pk name)
-					   (filter copyright? copyrights))))
-				   ))
+				   (copyrights-of lof (basename name))))
 	      )
 	  ))
     res
@@ -502,133 +320,6 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
     (filter empty-copyr? copyr-list))
   )
 
-
-;;; Function to do things with transforms that are defined below.
-(define (str-transfm transform)
-  (lambda (str)
-    (let* ((cre (car transform))
-	   (subst-str (cadr transform))
-	   (m? (regexp-exec cre str))
-	   )
-      (if m?
-	  (regexp-substitute
-	   #f
-	   m?
-	   'pre
-	   subst-str
-	   'post)
-	  str))))
-
-(define (gbl-str-transfm transform)
-  (lambda (str)
-    (let* ((cre (car transform))
-	   (subst-str (cadr transform))
-	   )
-      (regexp-substitute/global
-       #f
-       cre
-       str
-       'pre
-       subst-str
-       'post)
-      )))
-
-;;; Defining some simple string transformations.  They define regular expressions that
-;;; when matched are replaced by a string constant.
-;;;
-;;; They are simple and composable.
-(define non-lic-chars (list
-		       (make-regexp "[|_]+" regexp/extended) ""))
-(define invalid-lic-1 (list
-		       (make-regexp "GPL-2\\.0-or-later" regexp/basic) "GPL-2.0+"))
-(define invalid-lic-2 (list (make-regexp "GPL-2\\.0-only" regexp/basic) "GPL-2.0"))
-(define invalid-lic-3 (list
-		       (make-regexp "GPL-3\\.0-or-later" regexp/basic) "GPL-3.0+"))
-(define invalid-lic-4 (list
-		       (make-regexp "GPL-3\\.0-only" regexp/basic) "GPL-3.0"))
-(define GPL-space-to-hyphen (list (make-regexp "GPL 2" regexp/basic) "GPL-2"))
-(define or-later (list (make-regexp "-or-later ") "+ "))
-
-;; Here we compose multiple transforms into a single operation.
-(define spdx-license-canonicalize
-  (compose
-   (gbl-str-transfm non-lic-chars)
-   (str-transfm invalid-lic-1)
-   (str-transfm invalid-lic-2)
-   (str-transfm invalid-lic-3)
-   (str-transfm invalid-lic-4)
-   (str-transfm GPL-space-to-hyphen)
-   (str-transfm or-later)
-   ))
-
-(define (spdx-license? lof)
-  (spdx-license-auxx lof #f 15))
-
-(define spdx-raw-re (make-regexp "([-[:alpha:]]+):[:space:]*(.*)"))
-
-(define spdx-lic-raw-re
-  (make-regexp "SPDX-License-Identifier:[[:space:]]*(.*)"))
-(define spdx-lic-dquot-re
-  (make-regexp "SPDX-License-Identifier:[[:space:]]*\"(.*)\""))
-(define spdx-lic-cparen-re
-  (make-regexp "SPDX-License-Identifier:[[:space:]]*\\((.*)\\)"))
-
-(define prune-end-comment-re
-  (make-regexp "(.*)[[:space:]]*\\*/"))
-
-(define (spdx-license-identifier-value-raw line)
-  (let ((value+end
-	 (cond
-	  ((regexp-exec spdx-lic-cparen-re line) => (cut match:substring <> 1))
-	  ((regexp-exec spdx-lic-dquot-re line) => (cut match:substring <> 1))
-	  ((regexp-exec spdx-lic-raw-re line) => (cut match:substring <> 1))
-	  (else #f))))
-    (if value+end
-	(let ((end-comment-match? (regexp-exec prune-end-comment-re value+end)))
-	  (string-trim-right (if end-comment-match?
-				 (match:substring end-comment-match? 1)
-				 value+end)))
-	#f
-	)
-    )
-  )
-
-(define (spdx-license-identifier-value line)
-  (let ((raw-license-identifier (spdx-license-identifier-value-raw line)))
-    (if (string? raw-license-identifier)
-	(string->symbol
-	 (spdx-license-canonicalize
-	  raw-license-identifier))
-	raw-license-identifier)
-    )
-  )
-
-(define (spdx-license-auxx lof res lines-to-check)
-  (if (or (null? lof) res (< lines-to-check 1))
-      res
-      (spdx-license-auxx
-       (cdr lof)
-       (spdx-license-identifier-value (car lof))
-       (- lines-to-check 1)
-       )
-      )
-  )
-  
-
-;;; Unified licensing policy
-(define (licensing? text-lic spdx-lic)
-  (cond ((not (or text-lic spdx-lic)) ;; No license found
-	 #f)
-	((and text-lic spdx-lic) ;; Both licenses found
-	 (if (eq? text-lic spdx-lic)
-	     text-lic
-	     (if (eq? text-lic 'UNKNOWN)
-		 spdx-lic
-		 text-lic)))
-	((or text-lic spdx-lic) => identity) 
-	))
-
-;;; Revised base-cut-leaf to incorporate SPDX license information if available.
 (define (base-cut-leaf base-dir exclusion-func)
   (let ((trim-base (lambda (name)
 		     (let ((lbd (string-length base-dir)))
@@ -641,53 +332,31 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
     (lambda (name stat result)
       (let ((res result))
 	(if (exclusion-func name stat result) ;;#t or (string-match ".*\\.(scm|po)$" name)
-	    (let* ((lof (lines-of-file name))
-		   (text-lic? (and (lof-contains-license? lof)
-				  (license-of lof license-tests)
-				  )
-			      )
-		   (spdx-lic? (spdx-license? lof))
-		   )
-	      (hash-set! res name (make-licensed-file
-				   (trim-base name)
-				   (dir-from-full-file-name name)
-				   (licensing? text-lic? spdx-lic?)
-				   (filter copyright?
-				    (copyrights-of lof (basename name)))))
-		  
+	    (let ((lof (lines-of-file name))
+		  )
+	      (if (lof-contains-license? lof)
+		  (hash-set! res name (make-licensed-file
+				       (trim-base name)
+				       (dir-from-full-file-name name)
+				       (license-of lof license-tests)
+				       (filter-empty-copyrights
+					(copyrights-of lof (basename name)))))
+		  )
 	      ))
 	res
 	))))
 
-
 (define (up name stat results) results)
 (define (down name stat results) results)
 (define (skip name stat results) results)
 (define (err name stat errno results) results)
 
-(define (analyze-single-file fn)
-  "Provide the analysis for a single file.  For testing."
-  (let* ((lof (lines-of-file fn))
-	 (text-lic? (and (lof-contains-license? lof)
-			 (license-of lof license-tests)))
-	 (spdx-lic? (spdx-license? lof))
-	 (copyrights (copyrights-of lof (basename fn))))
-    (format #t "Prose-license: ~a~%SPDX-license: ~a~%Arbit: ~a~%Copyrights: ~a~%"
-	    text-lic?
-	    spdx-lic?
-	    (licensing? text-lic? spdx-lic?)
-	    (string-join
-	     (map (lambda (x) (format #f "~a" x)) copyrights)
-	     "\n"))
-    ))
-
 (define (hash-for-dir-tree dir)
   "Main entry point to scan a directory tree and return a hash of all files with license and copyright analyses."
   (let ((leaf (base-cut-leaf dir (const #t))))
     (file-system-fold enter? (base-cut-leaf dir (const #t)) down up skip err
 		      (make-hash-table 1200)
-		      dir
-		      stat)))
+		      dir)))
 
 (define (enter-w-exclusions? excl-list)
   "Provided a set of regular-expressions return an enter? function. Delimited defined by excl-delim-char"
@@ -706,8 +375,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 	(enter? (enter-w-exclusions? regexp-list)))
     (file-system-fold enter? leaf down up skip err
 		      (make-hash-table 1200)
-		      dir
-		      stat)))
+		      dir)))
 
 (define (problems-to-investigate dir)
   (let ((loc-hash (hash-for-dir-tree dir)))
@@ -752,7 +420,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 	(down (lambda  (name stat result) result))
 	(err (lambda  (name stat errno result) result))
 	)
-    (file-system-fold entry? leaf down up skip err '() base-dir stat)))
+    (file-system-fold entry? leaf down up skip err '() base-dir)))
 
 (define (single-licensed-dir? dir hash)
   (let ((lic-lst (license-freq dir hash)))
@@ -890,7 +558,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 (set-record-type-printer!
  <copyright>
  (lambda (rec port)
-   (format port "~a ~a~%"
+   (format port " ~a ~a~%"
 	   (display-cprt-yrs (copyright-year-list rec))
 	   (copyright-tag rec))))
 (set-record-type-printer!
@@ -902,22 +570,16 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 		 "File: ~a~%Copyright:\n~a~%License: ~a~%"
 		 name
 		 (string-join
-		  (map (lambda (copyr-rec)
-			 (format #f "~a ~a"
-				 (display-cprt-yrs
-				  (copyright-year-list copyr-rec))
-				 (copyright-tag copyr-rec))
-			 ;; (string-concatenate
-			 ;;  (list
-			 ;;   " "
-			 ;;   (display-cprt-yrs
-			 ;;    (copyright-year-list copyr-rec))
-			 ;;   " "
-			 ;;   (copyright-tag copyr-rec)))
-			       )
+		  (map (lambda (copyr-rec) (string-concatenate
+					    (list
+					     " "
+					     (display-cprt-yrs
+					      (copyright-year-list copyr-rec))
+					     " "
+					     (copyright-tag copyr-rec))))
 		       (licensed-file-copyright-list rec))
 		  "\n")
-		 (licensed-file-license->string rec))
+		 (licensed-file-license rec))
 	 (format port
 		 "Copyright:\n~a~%License: ~a~%"
 		 (let ((copr-l (sort-copyrights-by-tag-then-first-4 (licensed-file-copyright-list rec))))
@@ -934,7 +596,7 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 				   (copyright-tag copyr)))))
 			     copr-l)
 			"\n")))
-		 (licensed-file-license->string rec))
+		 (licensed-file-license rec))
 	 ))))
 
 (define (all-output dir-tree exclusion-list)
@@ -948,20 +610,11 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
      sorted-al)
     ))
 
-;; (define (license-filename-sort d-hash licenses)
-;;   (sort licenses
-;; 	(lambda (x y)
-;; 	  (string<=?
-;; 	   (licensed-file-name (licensed-files/license d-hash x))
-;; 	   (licensed-file-name (licensed-files/license d-hash y))
-;; 		     ))))
-
 (define (default-output dir-tree exclusion-list)
   (let* ((d-hash (hash-for-dir-tree-w-exclusions dir-tree exclusion-list))
 	 (license-freqs (license-counts d-hash (licenses-found d-hash)))
-	 (license-freqs-wo-falses (remove (lambda (x) (eq? (car x) #f)) license-freqs))
-	 (dominant-lic (caar license-freqs-wo-falses))
-	 (rem-licenses (map car (cdr license-freqs-wo-falses)))
+	 (dominant-lic (caar license-freqs))
+	 (rem-licenses (map car (cdr license-freqs)))
 	 )
     (format #t "Files: *~%~a~%"
 	    (licensed-files/license d-hash dominant-lic))
@@ -970,11 +623,10 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
        (let ((licensed-file-rec (licensed-files/license d-hash lic)))
 	 (format #t "Files:\n ~a~%"
 		 (string-join
-		  (sort (licensed-file-name licensed-file-rec)
-			string<=?) "\n "))
+		   (licensed-file-name licensed-file-rec) "\n "))
 	 (display licensed-file-rec)
 	 (newline)))
-     rem-licenses )
+     rem-licenses)
     ))
 
 (define (margs opt-name parsed-opts default-regexp)
@@ -987,15 +639,13 @@ returns \"1995,2005\".  Or the empty string for no copyrights."
 
 
 (define (start args)
-  (let* ((option-spec '((single-file (single-char #\f) (value #t))
-			(dir (single-char #\d) (value #t))
+  (let* ((option-spec '((dir (single-char #\d) (value #t))
 			(exclusions (single-char #\x) (value #t))
 			(list-files (single-char #\L) (value #f))
 			(short-years (single-char #\s) (value #f))
 			(all (single-char #\A) (value #f))
 			(help (single-char #\h) (value #f))))
 	 (options (getopt-long args option-spec))
-	 (filename (option-ref options 'single-file #f))
 	 (dir-provided (option-ref options 'dir #f))
 	 (ex-list (margs 'exclusions options '()))
 	 (list-files (option-ref options 'list-files #f))
@@ -1012,8 +662,6 @@ debian-copyrighter [options]
   -x,  --exclusions Possibly multiple regular-expressions for
                dirs and/or files to be excluded from analysis
   -A,  --all   Lists license, copyright holders for all files (long)
-  -f,  --single-file (pre-empts -d, -x, and -A) Analyze the given 
-               filename (for testing).
 
 Scans the provided dir for files containing license
 information and outputs collective summary of copyright holder
@@ -1026,21 +674,16 @@ command line.
 
 If -A is selected each file is listed individually.  Suited for
 filtering, troubleshooting or exploration.
-
-If -f <filename> provide a summary of what information is found within.
 "))
     (if shorten-years (set! display-cprt-yrs min-max-yr-lst))
-    (if filename
-	(analyze-single-file filename)
-	(if dir-provided
-	    (cond
-	     (all (all-output dir-provided ex-list))
-	     (list-files #t)
-	     (#t (begin
-		   (display (string-concatenate (list "Scanning: " dir-provided "\n")))
-		   (default-output dir-provided ex-list))))
-	    (display "Must provide the directory to read using the -d option. Or get --help.\n")
-	    ))
-    (display diagnostic-str)
+    (if dir-provided
+	(cond
+	 (all (all-output dir-provided ex-list))
+	 (list-files #t)
+	 (#t (begin
+	       (display (string-concatenate (list "Scanning: " dir-provided "\n")))
+	       (default-output dir-provided ex-list))))
+	(display "Must provide the directory to read using the -d option. Or get --help.\n")
+	)
     )
   )
